Package: SimVitD
Type: Package
Title: Simulation Tools for Planning Vitamin D Studies
Version: 1.0.5
Authors@R: c( person( "Rebecca", "Mangan", email="manganre@tcd.ie", role = c( "aut" ) ), person(  "Jason", "Wyse", email = "wyseja@tcd.ie", role = c("aut","cre") ), person("Lina", "Zgaga", email="zgagal@tcd.ie", role= "aut") )
Description: Simulation tools for planning Vitamin D studies. Individual vitamin D status 
             profiles are simulated, modelling population heterogeneity in trial arms. 
             Exposures to infectious agents are generated, with infection depending on vitamin D status.  
License: GPL (>= 2)
Maintainer: Jason Wyse <wyseja@tcd.ie>
Imports: simpleboot
Suggests: parallel
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-07-16 15:30:46 UTC; jason
Author: Rebecca Mangan [aut],
  Jason Wyse [aut, cre],
  Lina Zgaga [aut]
Repository: CRAN
Date/Publication: 2026-07-16 16:20:02 UTC
